// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "notificationinhibition_debug.h"


Q_LOGGING_CATEGORY(XdgDesktopPortalKdeNotificationInhibition, "xdp-kde-notificationinhibition", QtInfoMsg)

