// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "remotedesktop_debug.h"


Q_LOGGING_CATEGORY(XdgDesktopPortalKdeRemoteDesktop, "xdp-kde-remotedesktop", QtInfoMsg)

