/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KWin.VirtualKeyboard.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef VIRTUALKEYBOARD_INTERFACE_H
#define VIRTUALKEYBOARD_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.kwin.VirtualKeyboard
 */
class OrgKdeKwinVirtualKeyboardInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.kwin.VirtualKeyboard"; }

public:
    OrgKdeKwinVirtualKeyboardInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKwinVirtualKeyboardInterface();

    Q_PROPERTY(bool active READ active WRITE setActive)
    inline bool active() const
    { return qvariant_cast< bool >(property("active")); }
    inline void setActive(bool value)
    { setProperty("active", QVariant::fromValue(value)); }

    Q_PROPERTY(bool activeClientSupportsTextInput READ activeClientSupportsTextInput)
    inline bool activeClientSupportsTextInput() const
    { return qvariant_cast< bool >(property("activeClientSupportsTextInput")); }

    Q_PROPERTY(bool available READ available)
    inline bool available() const
    { return qvariant_cast< bool >(property("available")); }

    Q_PROPERTY(bool enabled READ enabled WRITE setEnabled)
    inline bool enabled() const
    { return qvariant_cast< bool >(property("enabled")); }
    inline void setEnabled(bool value)
    { setProperty("enabled", QVariant::fromValue(value)); }

    Q_PROPERTY(bool visible READ visible)
    inline bool visible() const
    { return qvariant_cast< bool >(property("visible")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> forceActivate()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("forceActivate"), argumentList);
    }

    inline QDBusPendingReply<bool> willShowOnActive()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("willShowOnActive"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void activeChanged();
    void activeClientSupportsTextInputChanged();
    void availableChanged();
    void enabledChanged();
    void visibleChanged();
};

namespace org {
  namespace kde {
    namespace kwin {
      using VirtualKeyboard = ::OrgKdeKwinVirtualKeyboardInterface;
    }
  }
}

#endif
