/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Accounts.User.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef USER_INTERFACE_H
#define USER_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.Accounts.User
 */
class OrgFreedesktopAccountsUserInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.Accounts.User"; }

public:
    OrgFreedesktopAccountsUserInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopAccountsUserInterface();

    Q_PROPERTY(QString IconFile READ iconFile)
    inline QString iconFile() const
    { return qvariant_cast< QString >(property("IconFile")); }

    Q_PROPERTY(QString RealName READ realName)
    inline QString realName() const
    { return qvariant_cast< QString >(property("RealName")); }

    Q_PROPERTY(QString UserName READ userName)
    inline QString userName() const
    { return qvariant_cast< QString >(property("UserName")); }

public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
    void Changed();
};

#endif
