/****************************************************************************
** Meta object code from reading C++ file 'kglobalaccel_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "kglobalaccel_interface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kglobalaccel_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21KGlobalAccelInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto KGlobalAccelInterface::qt_create_metaobjectdata<qt_meta_tag_ZN21KGlobalAccelInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGlobalAccelInterface",
        "yourShortcutGotChanged",
        "",
        "actionId",
        "QList<int>",
        "newKeys",
        "yourShortcutsChanged",
        "QList<QKeySequence>",
        "action",
        "QDBusPendingReply<QStringList>",
        "key",
        "actionList",
        "QKeySequence",
        "activateGlobalShortcutContext",
        "QDBusPendingReply<>",
        "component",
        "context",
        "allActionsForComponent",
        "QDBusPendingReply<QList<QStringList>>",
        "allComponents",
        "QDBusPendingReply<QList<QDBusObjectPath>>",
        "allMainComponents",
        "blockGlobalShortcuts",
        "in0",
        "defaultShortcut",
        "QDBusPendingReply<QList<int>>",
        "defaultShortcutKeys",
        "QDBusPendingReply<QList<QKeySequence>>",
        "doRegister",
        "getComponent",
        "QDBusPendingReply<QDBusObjectPath>",
        "componentUnique",
        "getGlobalShortcutsByKey",
        "QDBusPendingReply<QList<KGlobalShortcutInfo>>",
        "globalShortcutAvailable",
        "QDBusPendingReply<bool>",
        "globalShortcutsByKey",
        "KGlobalAccel::MatchType",
        "matchType",
        "isGlobalShortcutAvailable",
        "setForeignShortcut",
        "keys",
        "setForeignShortcutKeys",
        "setInactive",
        "setShortcut",
        "flags",
        "setShortcutKeys",
        "shortcut",
        "shortcutKeys",
        "unRegister",
        "unregister",
        "shortcutUnique"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'yourShortcutGotChanged'
        QtMocHelpers::SignalData<void(const QStringList &, const QList<int> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'yourShortcutsChanged'
        QtMocHelpers::SignalData<void(const QStringList &, const QList<QKeySequence> &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 }, { 0x80000000 | 7, 5 },
        }}),
        // Slot 'action'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(int)>(8, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'actionList'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(const QKeySequence &)>(11, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { 0x80000000 | 12, 10 },
        }}),
        // Slot 'activateGlobalShortcutContext'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(13, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'allActionsForComponent'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QStringList> >(const QStringList &)>(17, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'allComponents'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QDBusObjectPath> >()>(19, 2, QMC::AccessPublic, 0x80000000 | 20),
        // Slot 'allMainComponents'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QStringList> >()>(21, 2, QMC::AccessPublic, 0x80000000 | 18),
        // Slot 'blockGlobalShortcuts'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(22, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'defaultShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<int> >(const QStringList &)>(24, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'defaultShortcutKeys'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QKeySequence> >(const QStringList &)>(26, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'doRegister'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(28, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'getComponent'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &)>(29, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'getGlobalShortcutsByKey'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<KGlobalShortcutInfo> >(int)>(32, 2, QMC::AccessPublic, 0x80000000 | 33, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'globalShortcutAvailable'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QKeySequence &, const QString &)>(34, 2, QMC::AccessPublic, 0x80000000 | 35, {{
            { 0x80000000 | 12, 10 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'globalShortcutsByKey'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<KGlobalShortcutInfo> >(const QKeySequence &, KGlobalAccel::MatchType)>(36, 2, QMC::AccessPublic, 0x80000000 | 33, {{
            { 0x80000000 | 12, 10 }, { 0x80000000 | 37, 38 },
        }}),
        // Slot 'isGlobalShortcutAvailable'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(int, const QString &)>(39, 2, QMC::AccessPublic, 0x80000000 | 35, {{
            { QMetaType::Int, 10 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'setForeignShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &, const QList<int> &)>(40, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QStringList, 3 }, { 0x80000000 | 4, 41 },
        }}),
        // Slot 'setForeignShortcutKeys'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &, const QList<QKeySequence> &)>(42, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QStringList, 3 }, { 0x80000000 | 7, 41 },
        }}),
        // Slot 'setInactive'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(43, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'setShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<int> >(const QStringList &, const QList<int> &, uint)>(44, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QStringList, 3 }, { 0x80000000 | 4, 41 }, { QMetaType::UInt, 45 },
        }}),
        // Slot 'setShortcutKeys'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QKeySequence> >(const QStringList &, const QList<QKeySequence> &, uint)>(46, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QStringList, 3 }, { 0x80000000 | 7, 41 }, { QMetaType::UInt, 45 },
        }}),
        // Slot 'shortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<int> >(const QStringList &)>(47, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'shortcutKeys'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QKeySequence> >(const QStringList &)>(48, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'unRegister'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(49, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'unregister'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &, const QString &)>(50, 2, QMC::AccessPublic, 0x80000000 | 35, {{
            { QMetaType::QString, 31 }, { QMetaType::QString, 51 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KGlobalAccelInterface, qt_meta_tag_ZN21KGlobalAccelInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KGlobalAccelInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KGlobalAccelInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KGlobalAccelInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21KGlobalAccelInterfaceE_t>.metaTypes,
    nullptr
} };

void KGlobalAccelInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KGlobalAccelInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->yourShortcutGotChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2]))); break;
        case 1: _t->yourShortcutsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QKeySequence>>>(_a[2]))); break;
        case 2: { QDBusPendingReply<QStringList> _r = _t->action((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QStringList> _r = _t->actionList((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->activateGlobalShortcutContext((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<QList<QStringList>> _r = _t->allActionsForComponent((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QStringList>>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<QList<QDBusObjectPath>> _r = _t->allComponents();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QDBusObjectPath>>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<QList<QStringList>> _r = _t->allMainComponents();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QStringList>>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->blockGlobalShortcuts((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<QList<int>> _r = _t->defaultShortcut((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<int>>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<QList<QKeySequence>> _r = _t->defaultShortcutKeys((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QKeySequence>>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->doRegister((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<QDBusObjectPath> _r = _t->getComponent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<QList<KGlobalShortcutInfo>> _r = _t->getGlobalShortcutsByKey((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<KGlobalShortcutInfo>>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<bool> _r = _t->globalShortcutAvailable((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<QList<KGlobalShortcutInfo>> _r = _t->globalShortcutsByKey((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KGlobalAccel::MatchType>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<KGlobalShortcutInfo>>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<bool> _r = _t->isGlobalShortcutAvailable((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->setForeignShortcut((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->setForeignShortcutKeys((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QKeySequence>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->setInactive((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<QList<int>> _r = _t->setShortcut((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<int>>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<QList<QKeySequence>> _r = _t->setShortcutKeys((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QKeySequence>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QKeySequence>>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<QList<int>> _r = _t->shortcut((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<int>>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<QList<QKeySequence>> _r = _t->shortcutKeys((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QKeySequence>>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->unRegister((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<bool> _r = _t->unregister((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KGlobalAccelInterface::*)(const QStringList & , const QList<int> & )>(_a, &KGlobalAccelInterface::yourShortcutGotChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGlobalAccelInterface::*)(const QStringList & , const QList<QKeySequence> & )>(_a, &KGlobalAccelInterface::yourShortcutsChanged, 1))
            return;
    }
}

const QMetaObject *KGlobalAccelInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGlobalAccelInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KGlobalAccelInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int KGlobalAccelInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void KGlobalAccelInterface::yourShortcutGotChanged(const QStringList & _t1, const QList<int> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KGlobalAccelInterface::yourShortcutsChanged(const QStringList & _t1, const QList<QKeySequence> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
