/****************************************************************************
** Meta object code from reading C++ file 'appchooserdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../xdg-desktop-portal-kde-6.6.90/src/appchooserdialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appchooserdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14AppFilterModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AppFilterModel::qt_create_metaobjectdata<qt_meta_tag_ZN14AppFilterModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AppFilterModel",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Provided by C++ side via properties",
        "showOnlyPreferredAppsChanged",
        "",
        "filterChanged",
        "showOnlyPreferredApps",
        "filter"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showOnlyPreferredAppsChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'showOnlyPreferredApps'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'filter'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<AppFilterModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AppFilterModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AppFilterModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AppFilterModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14AppFilterModelE_t>.metaTypes,
    nullptr
} };

void AppFilterModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AppFilterModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showOnlyPreferredAppsChanged(); break;
        case 1: _t->filterChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AppFilterModel::*)()>(_a, &AppFilterModel::showOnlyPreferredAppsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppFilterModel::*)()>(_a, &AppFilterModel::filterChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->showOnlyPreferredApps(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->filter(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setShowOnlyPreferredApps(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setFilter(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AppFilterModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AppFilterModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AppFilterModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int AppFilterModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void AppFilterModel::showOnlyPreferredAppsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AppFilterModel::filterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN14AppChooserDataE_t {};
} // unnamed namespace

template <> constexpr inline auto AppChooserData::qt_create_metaobjectdata<qt_meta_tag_ZN14AppChooserDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AppChooserData",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Provided by C++ side via properties",
        "fileNameChanged",
        "",
        "defaultAppChanged",
        "lastUsedAppChanged",
        "mimeNameChanged",
        "mimeDescChanged",
        "historyChanged",
        "shellAccessChanged",
        "rememberChanged",
        "openInTerminalChanged",
        "lingerTerminalChanged",
        "applicationSelected",
        "desktopFile",
        "remember",
        "openDiscover",
        "fileDialogFinished",
        "selectedFile",
        "openFileDialog",
        "QWindow*",
        "parent",
        "fileName",
        "defaultApp",
        "lastUsedApp",
        "mimeName",
        "mimeDesc",
        "history",
        "shellAccess",
        "openInTerminal",
        "lingerTerminal"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fileNameChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultAppChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastUsedAppChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mimeNameChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mimeDescChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'historyChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shellAccessChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rememberChanged'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openInTerminalChanged'
        QtMocHelpers::SignalData<void()>(16, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lingerTerminalChanged'
        QtMocHelpers::SignalData<void()>(17, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'applicationSelected'
        QtMocHelpers::SignalData<void(const QString &, bool)>(18, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { QMetaType::Bool, 20 },
        }}),
        // Signal 'applicationSelected'
        QtMocHelpers::SignalData<void(const QString &)>(18, 8, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Signal 'openDiscover'
        QtMocHelpers::SignalData<void()>(21, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileDialogFinished'
        QtMocHelpers::SignalData<void(const QString &)>(22, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'openFileDialog'
        QtMocHelpers::SlotData<void(QWindow *)>(24, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'openFileDialog'
        QtMocHelpers::SlotData<void()>(24, 8, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'fileName'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'defaultApp'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'lastUsedApp'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'mimeName'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'mimeDesc'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'history'
        QtMocHelpers::PropertyData<QStringList>(32, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable, 5),
        // property 'shellAccess'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 6),
        // property 'remember'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 7),
        // property 'openInTerminal'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 8),
        // property 'lingerTerminal'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<AppChooserData, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AppChooserData::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AppChooserDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AppChooserDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14AppChooserDataE_t>.metaTypes,
    nullptr
} };

void AppChooserData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AppChooserData *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fileNameChanged(); break;
        case 1: _t->defaultAppChanged(); break;
        case 2: _t->lastUsedAppChanged(); break;
        case 3: _t->mimeNameChanged(); break;
        case 4: _t->mimeDescChanged(); break;
        case 5: _t->historyChanged(); break;
        case 6: _t->shellAccessChanged(); break;
        case 7: _t->rememberChanged(); break;
        case 8: _t->openInTerminalChanged(); break;
        case 9: _t->lingerTerminalChanged(); break;
        case 10: _t->applicationSelected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 11: _t->applicationSelected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->openDiscover(); break;
        case 13: _t->fileDialogFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->openFileDialog((*reinterpret_cast<std::add_pointer_t<QWindow*>>(_a[1]))); break;
        case 15: _t->openFileDialog(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWindow* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AppChooserData::*)()>(_a, &AppChooserData::fileNameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppChooserData::*)()>(_a, &AppChooserData::defaultAppChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppChooserData::*)()>(_a, &AppChooserData::lastUsedAppChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppChooserData::*)()>(_a, &AppChooserData::mimeNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppChooserData::*)()>(_a, &AppChooserData::mimeDescChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppChooserData::*)()>(_a, &AppChooserData::historyChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppChooserData::*)()>(_a, &AppChooserData::shellAccessChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppChooserData::*)()>(_a, &AppChooserData::rememberChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppChooserData::*)()>(_a, &AppChooserData::openInTerminalChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppChooserData::*)()>(_a, &AppChooserData::lingerTerminalChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppChooserData::*)(const QString & , bool )>(_a, &AppChooserData::applicationSelected, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppChooserData::*)()>(_a, &AppChooserData::openDiscover, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppChooserData::*)(const QString & )>(_a, &AppChooserData::fileDialogFinished, 13))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->fileName(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->defaultApp(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->lastUsedApp(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->mimeName(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->mimeDesc(); break;
        case 5: *reinterpret_cast<QStringList*>(_v) = _t->m_history; break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->m_shellAccess; break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->m_remember; break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->m_openInTerminal; break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->m_lingerTerminal; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFileName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setDefaultApp(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setLastUsedApp(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setMimeName(*reinterpret_cast<QString*>(_v)); break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_history, *reinterpret_cast<QStringList*>(_v)))
                Q_EMIT _t->historyChanged();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->m_shellAccess, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->shellAccessChanged();
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_remember, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->rememberChanged();
            break;
        case 8:
            if (QtMocHelpers::setProperty(_t->m_openInTerminal, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->openInTerminalChanged();
            break;
        case 9:
            if (QtMocHelpers::setProperty(_t->m_lingerTerminal, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->lingerTerminalChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *AppChooserData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AppChooserData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AppChooserDataE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AppChooserData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void AppChooserData::fileNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AppChooserData::defaultAppChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AppChooserData::lastUsedAppChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AppChooserData::mimeNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AppChooserData::mimeDescChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AppChooserData::historyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AppChooserData::shellAccessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AppChooserData::rememberChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AppChooserData::openInTerminalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void AppChooserData::lingerTerminalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void AppChooserData::applicationSelected(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 12
void AppChooserData::openDiscover()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void AppChooserData::fileDialogFinished(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN8AppModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AppModel::qt_create_metaobjectdata<qt_meta_tag_ZN8AppModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AppModel",
        "hasPreferredAppsChanged",
        "",
        "hasPreferredApps"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'hasPreferredAppsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'hasPreferredApps'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AppModel, qt_meta_tag_ZN8AppModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AppModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8AppModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8AppModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8AppModelE_t>.metaTypes,
    nullptr
} };

void AppModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AppModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->hasPreferredAppsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AppModel::*)()>(_a, &AppModel::hasPreferredAppsChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->m_hasPreferredApps; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_hasPreferredApps, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->hasPreferredAppsChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *AppModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AppModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8AppModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int AppModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void AppModel::hasPreferredAppsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN16AppChooserDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto AppChooserDialog::qt_create_metaobjectdata<qt_meta_tag_ZN16AppChooserDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AppChooserDialog",
        "onApplicationSelected",
        "",
        "desktopFile",
        "remember",
        "onOpenDiscover"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onApplicationSelected'
        QtMocHelpers::SlotData<void(const QString &, const bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 4 },
        }}),
        // Slot 'onApplicationSelected'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'onOpenDiscover'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AppChooserDialog, qt_meta_tag_ZN16AppChooserDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AppChooserDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QuickDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AppChooserDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AppChooserDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16AppChooserDialogE_t>.metaTypes,
    nullptr
} };

void AppChooserDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AppChooserDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onApplicationSelected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->onApplicationSelected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->onOpenDiscover(); break;
        default: ;
        }
    }
}

const QMetaObject *AppChooserDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AppChooserDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AppChooserDialogE_t>.strings))
        return static_cast<void*>(this);
    return QuickDialog::qt_metacast(_clname);
}

int AppChooserDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QuickDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
