/****************************************************************************
** Meta object code from reading C++ file 'SelectionEditor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../xdg-desktop-portal-kde-6.6.90/src/region-select/SelectionEditor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SelectionEditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15SelectionEditorE_t {};
} // unnamed namespace

template <> constexpr inline auto SelectionEditor::qt_create_metaobjectdata<qt_meta_tag_ZN15SelectionEditorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SelectionEditor",
        "rectChanged",
        "",
        "emptyChanged",
        "isDraggingChanged",
        "finished",
        "DialogResult",
        "result",
        "dragStart",
        "screenName",
        "x",
        "y",
        "setMousePosition",
        "dragRelease",
        "dragReset",
        "reject",
        "rect",
        "QRect",
        "isDragging"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'rectChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emptyChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isDraggingChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finished'
        QtMocHelpers::SignalData<void(DialogResult)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Method 'dragStart'
        QtMocHelpers::MethodData<void(const QString &, int, int)>(8, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Method 'setMousePosition'
        QtMocHelpers::MethodData<void(const QString &, int, int)>(12, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Method 'dragRelease'
        QtMocHelpers::MethodData<void(const QString &, int, int)>(13, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Method 'dragReset'
        QtMocHelpers::MethodData<void()>(14, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'reject'
        QtMocHelpers::MethodData<void()>(15, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'rect'
        QtMocHelpers::PropertyData<QRect>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'isDragging'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SelectionEditor, qt_meta_tag_ZN15SelectionEditorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SelectionEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SelectionEditorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SelectionEditorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SelectionEditorE_t>.metaTypes,
    nullptr
} };

void SelectionEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SelectionEditor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->rectChanged(); break;
        case 1: _t->emptyChanged(); break;
        case 2: _t->isDraggingChanged(); break;
        case 3: _t->finished((*reinterpret_cast<std::add_pointer_t<DialogResult>>(_a[1]))); break;
        case 4: _t->dragStart((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 5: _t->setMousePosition((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->dragRelease((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 7: _t->dragReset(); break;
        case 8: _t->reject(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SelectionEditor::*)()>(_a, &SelectionEditor::rectChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectionEditor::*)()>(_a, &SelectionEditor::emptyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectionEditor::*)()>(_a, &SelectionEditor::isDraggingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectionEditor::*)(DialogResult )>(_a, &SelectionEditor::finished, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QRect*>(_v) = _t->rect(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isDragging(); break;
        default: break;
        }
    }
}

const QMetaObject *SelectionEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SelectionEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SelectionEditorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SelectionEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void SelectionEditor::rectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SelectionEditor::emptyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SelectionEditor::isDraggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SelectionEditor::finished(DialogResult _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
