// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "remotedesktopdialog_debug.h"


Q_LOGGING_CATEGORY(XdgDesktopPortalKdeRemoteDesktopDialog, "xdp-kde-remote-desktop-dialog", QtInfoMsg)

